pyeasyga
========

|PyPI| |Build Status| |Coverage Status| |Downloads|


Introduction
------------
A simple and easy-to-use Genetic Algorithm implementation library in Python.

``pyeasyga`` provides a simple interface to the power of Genetic Algorithms
(GAs). You don't have to have expert GA knowledge in order to use it.

* Homepage: https://github.com/remiomosowon/pyeasyga
* PyPI: https://pypi.python.org/pypi/pyeasyga
* Documentation: http://pyeasyga.readthedocs.org.
* Issues / Feedback: https://github.com/remiomosowon/pyeasyga/issues 
* Free software: BSD license


Installation
~~~~~~~~~~~~

At the command line, simply run: ::

    $ pip install pyeasyga

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv pyeasyga
    $ pip install pyeasyga


Examples
~~~~~~~~

See *Usage* for examples. The example files can be found in the 
``examples`` directory.


Note
-----

* Currently under active development


.. |PyPI| image:: https://badge.fury.io/py/pyeasyga.png
   :target: http://badge.fury.io/py/pyeasyga

.. |Build Status| image:: https://travis-ci.org/remiomosowon/pyeasyga.png?branch=develop
   :target: https://travis-ci.org/remiomosowon/pyeasyga

.. |Coverage Status| image:: https://coveralls.io/repos/remiomosowon/pyeasyga/badge.png?branch=develop
   :target: https://coveralls.io/r/remiomosowon/pyeasyga?branch=develop

.. |Downloads| image:: https://pypip.in/d/pyeasyga/badge.png
   :target: https://pypi.python.org/pypi/pyeasyga

